@@ -17,7 +17,7 @@ use Text::Abbrev();
 use Exporter ();
 our @ISA = qw{ Exporter };
 
-our $VERSION = '0.001_01';
+our $VERSION = '0.003_01';
 
 our @EXPORT_OK = qw{
     __am_or_pm
@@ -639,7 +639,7 @@ sub _fmt_on_date {
     $on_date[3][28]  = "Celeborn crosses the Anduin and begins destruction of Dol Guldur, 1419.\n";
 
     $on_date[4][6]   = "The mallorn tree flowers in the party field, 1420.\n";
-    $on_date[4][8]   = "Ring bearers are honored on the fields of Cormallen, 1419.\n";
+    $on_date[4][8]   = "Ring bearers are honored on the Field of Cormallen, 1419.\n";
     $on_date[4][12]  = "Gandalf arrives in Hobbiton, 1418\n";
 
     $on_date[5][1]   = "Crowning of King Elessar, 1419.\n" .
@@ -735,6 +735,7 @@ sub _fmt_on_date {
 			$day =~ s/ \b Nazgul \b /Nazg${u_circ}l/smxgo;
 			$day =~ s/ \b Theoden \b /Th${e_acute}oden/smxgo;
 			$day =~ s/ \b Theodred \b /Th${e_acute}odred/smxgo;
+			$day =~ s/ \b Udun \b /Ud${u_circ}n/smxgo;
 		    }
 		    push @{ $on_date_accented[-1] }, $day;
 		}
@@ -1995,7 +1996,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2017 by Thomas R. Wyant, III
+Copyright (C) 2017-2018 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
